@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.45 2002/03/23 17:26:34 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.48.2.2 2002/07/17 01:46:21 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -102,55 +102,56 @@ static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data
     return FALSE;
 }
 
-static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void about_cb (BonoboUIComponent *uic,
+		      GWeatherApplet    *gw_applet,
+		      const gchar       *verbname)
 {
 
-    gweather_about_run();
-    return;
-
+    gweather_about_run (gw_applet);
 }
 
-static void help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void help_cb (BonoboUIComponent *uic,
+		     GWeatherApplet    *gw_applet,
+		     const gchar       *verbname)
 {
-#ifdef FIXME
-    static GnomeHelpMenuEntry help_entry = { "gweather_applet", "index.html"};
-
-    gnome_help_display(NULL, &help_entry);
-#endif
+    GError *error = NULL;
+    gnome_help_display("gweather",NULL,&error);
+ 
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
 }
 
-static void pref_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void pref_cb (BonoboUIComponent *uic,
+		     GWeatherApplet    *gw_applet,
+		     const gchar       *verbname)
 {
-    GWeatherApplet *gw_applet = data;
-    gweather_pref_run(gw_applet);
-    return;
+    gweather_pref_run (gw_applet);
 }
 
-static void forecast_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void forecast_cb (BonoboUIComponent *uic,
+		         GWeatherApplet    *gw_applet,
+			 const gchar       *verbname)
 {
-    GWeatherApplet *gw_applet = data;
-
-    gweather_dialog_open(gw_applet);
-
-    return;
+    gweather_dialog_open (gw_applet);
 }
 
-static void update_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+static void update_cb (BonoboUIComponent *uic,
+		       GWeatherApplet    *gw_applet,
+		       const gchar       *verbname)
 {
-    GWeatherApplet *gw_applet = data;
-
-    gweather_update(gw_applet);
-
-    return;
+    gweather_update (gw_applet);
 }
 
 
 static const BonoboUIVerb weather_applet_menu_verbs [] = {
-	BONOBO_UI_VERB ("Forecast", forecast_cb),
-	BONOBO_UI_VERB ("Update", update_cb),
-        BONOBO_UI_VERB ("Props", pref_cb),
-/*        BONOBO_UI_VERB ("Help", help_cb), */
-        BONOBO_UI_VERB ("About", about_cb),
+	BONOBO_UI_UNSAFE_VERB ("Forecast", forecast_cb),
+	BONOBO_UI_UNSAFE_VERB ("Update", update_cb),
+        BONOBO_UI_UNSAFE_VERB ("Props", pref_cb),
+        BONOBO_UI_UNSAFE_VERB ("Help", help_cb), 
+        BONOBO_UI_UNSAFE_VERB ("About", about_cb),
 
         BONOBO_UI_VERB_END
 };
@@ -168,9 +169,9 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     gw_applet->gweather_pref.detailed = FALSE;
     gw_applet->gweather_pref.radar_enabled = TRUE;
     
-#if 0   
+ 
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gweather/tstorm.xpm");
-#endif
+
     /* PUSH */
     gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
@@ -187,10 +188,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 
     gtk_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
                        GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
-
-    g_signal_connect (G_OBJECT(gw_applet->applet), "destroy",
-                        G_CALLBACK(gtk_main_quit), NULL);
-                        
+                     
     tooltips = gtk_tooltips_new();
 
     gtk_tooltips_set_tip(tooltips, GTK_WIDGET(gw_applet->applet), _("GNOME Weather"), NULL);
@@ -277,9 +275,8 @@ void update_finish (WeatherInfo *info)
     }
 */
     /* Store current conditions */
-    
-    gw_applet->gweather_info = info;
    
+    gw_applet->gweather_info = info;
     weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
     				 &(gw_applet->applet_pixbuf));
     gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
@@ -313,8 +310,6 @@ void gweather_update (GWeatherApplet *gw_applet)
 {
     gboolean update_success;
 
-    /* Let user know we are updating */
-
     weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
     				 &(gw_applet->applet_pixbuf));
 
