@@ -46,5 +46,8 @@ properties * load_session(MCData *mcdata);
 
 gint save_session_signal(GtkWidget *widget, const char *privcfgpath, const char *globcfgpath);
 
-void properties_box(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+void properties_box (BonoboUIComponent *uic,
+		     MCData            *mcdata,
+		     const char        *verbname);
+
 #endif
