@@ -6,6 +6,7 @@
  *
  */
 
+#include <config.h>
 #include "modemlights.h"
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
@@ -82,9 +83,15 @@ void property_load(PanelApplet *applet)
 	g_free(buf);
 
 	command_connect    = panel_applet_gconf_get_string(applet, "connect", NULL);
+	if (!command_connect)
+		command_connect = g_strdup ("pppon");
 	command_disconnect = panel_applet_gconf_get_string(applet, "disconnect", NULL);
+	if (!command_disconnect)
+		command_disconnect = g_strdup ("pppoff");
 	ask_for_confirmation = panel_applet_gconf_get_int(applet, "confirmation", NULL);
 	device_name          = panel_applet_gconf_get_string(applet, "device", NULL);
+	if (!device_name)
+		device_name = g_strdup ("ppp0");
 	use_ISDN	   = panel_applet_gconf_get_int(applet, "isdn", NULL);
        	verify_lock_file   = panel_applet_gconf_get_int(applet, "verify_lock", NULL);
 	show_extra_info    = panel_applet_gconf_get_int(applet, "extra_info", NULL);
@@ -97,6 +104,7 @@ void property_load(PanelApplet *applet)
 		display_color_text[i] = panel_applet_gconf_get_string(applet, 
 							              color_rc_names[i], 
 							              NULL);
+		
 
 		}
 
@@ -295,9 +303,10 @@ property_response_cb (GtkDialog *dialog, gint id, gpointer data)
 	propwindow = NULL;
 }
 
-void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+void property_show (BonoboUIComponent *uic,
+		    PanelApplet       *applet,
+		    const gchar       *verbname)
 {
-	PanelApplet *applet = data;
 	GtkWidget *frame;
 	GtkWidget *hbox;
 	GtkWidget *notebook;
@@ -309,11 +318,10 @@ void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 	GtkWidget *checkbox;
 	GtkWidget *button;
 
-	if(propwindow)
-		{
-                gdk_window_raise(propwindow->window);
-                return;
-		}
+	if (propwindow) {
+		gtk_window_present (GTK_WINDOW (propwindow));
+		return;
+	}
 
         propwindow = gtk_dialog_new_with_buttons (_("Modem Lights Preferences"), NULL,
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -547,12 +555,4 @@ void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 			  G_CALLBACK (property_response_cb), NULL);
 
         gtk_widget_show_all(propwindow);
-        return;
-        applet = NULL;
-        data = NULL;
-        
-    
 } 
-
-
-
